/**
 * COOS - Connected Objects Operating System (www.connectedobjects.org).
 *
 * Copyright (C) 2009 Telenor ASA and Tellu AS. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * You may also contact one of the following for additional information:
 * Telenor ASA, Snaroyveien 30, N-1331 Fornebu, Norway (www.telenor.no)
 * Tellu AS, Hagalokkveien 13, N-1383 Asker, Norway (www.tellu.no)
 */
package org.coos.actorframe.threadpool;

import org.coos.javaframe.Logger;
import org.coos.javaframe.LoggerFactory;
import org.coos.javaframe.TraceObject;

/**
 * 
 * @author Knut Eilif Husa, Tellu AS
 */
public class ThreadPoolThread implements Runnable {
	private ThreadPool tp;
	private boolean active = false;
	private TraceObject trace = new TraceObject();

    private static Logger logger = LoggerFactory.getLogger("org.coos.javaframe");
    private String workerName;

	ThreadPoolThread(ThreadPool tp, int num) {
		this.tp = tp;
        this.workerName = tp.name + "_" + num;
		Thread t = new Thread(this, workerName);
        t.start();
	}

	public void run() {
        if (logger != null) {
            logger.log(Logger.DEBUG, "Worker " + workerName + " is started");
        }
		while (true) {
			try {
				// Get the next task from the parent ThreadPool
				ThreadPoolRunnable r = tp.getRunnable();
                if(r == null){
                    break;
                }
				// Make it use this threads trace object
				r.setTraceObject(trace);
				// Run the task!
				active = true;
				r.run();
				active = false;
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
       if (logger != null) {
            logger.log(Logger.DEBUG, "Worker " + workerName + " is stopped");
        }
	}

	public boolean active() {
		return active;
	}
}
